@@ -38,9 +38,7 @@
 #include "gcm-cell-renderer-color.h"
 #include "gcm-cie-widget.h"
 #include "gcm-image.h"
-#include "gcm-profile.h"
 #include "gcm-trc-widget.h"
-#include "gcm-named-color.h"
 #include "gcm-utils.h"
 #include "gcm-debug.h"
 
@@ -63,6 +61,7 @@ typedef struct {
 	gchar		*profile_id;
 	gchar		*filename;
 	guint		 xid;
+	const gchar	*lang;
 	GtkListStore	*liststore_nc;
 	GtkListStore	*liststore_metadata;
 } GcmViewerPrivate;
@@ -447,8 +446,8 @@ gcm_viewer_file_chooser_get_icc_profile (GcmViewerPrivate *viewer)
 	/* TRANSLATORS: dialog for file->open dialog */
 	dialog = gtk_file_chooser_dialog_new (_("Select ICC Profile File"), window,
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
-					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					       _("Import"), GTK_RESPONSE_ACCEPT,
+					       _("_Cancel"), GTK_RESPONSE_CANCEL,
+					       _("_Import"), GTK_RESPONSE_ACCEPT,
 					      NULL);
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), GCM_STOCK_ICON);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog), g_get_home_dir ());
@@ -740,44 +739,28 @@ gcm_viewer_profile_colorspace_to_string (CdColorspace colorspace)
  * gcm_viewer_add_named_colors:
  **/
 static gboolean
-gcm_viewer_add_named_colors (GcmViewerPrivate *viewer,
-			     GcmProfile *profile)
+gcm_viewer_add_named_colors (GcmViewerPrivate *viewer, CdIcc *icc)
 {
-	gboolean ret = FALSE;
-	GcmNamedColor *nc;
-	GError *error = NULL;
+	CdColorSwatch *nc;
 	GPtrArray *ncs = NULL;
 	GtkTreeIter iter;
 	guint i;
 
 	/* get profile named colors */
-	ncs = gcm_profile_get_named_colors (profile, &error);
-	if (ncs == NULL) {
-		g_warning ("failed to get named colors: %s",
-			   error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* add items */
 	gtk_list_store_clear (viewer->liststore_nc);
-	for (i=0; i<ncs->len; i++) {
+	ncs = cd_icc_get_named_colors (icc);
+	for (i = 0; i < ncs->len; i++) {
 		nc = g_ptr_array_index (ncs, i);
 		gtk_list_store_append (viewer->liststore_nc, &iter);
 		gtk_list_store_set (viewer->liststore_nc,
 				    &iter,
 				    GCM_NAMED_COLORS_COLUMN_SORT, "1",
-				    GCM_NAMED_COLORS_COLUMN_TITLE, gcm_named_color_get_title (nc),
-				    GCM_NAMED_COLORS_COLUMN_COLOR, gcm_named_color_get_value (nc),
+				    GCM_NAMED_COLORS_COLUMN_TITLE, cd_color_swatch_get_name (nc),
+				    GCM_NAMED_COLORS_COLUMN_COLOR, cd_color_swatch_get_value (nc),
 				    -1);
 	}
-
-	/* success */
-	ret= TRUE;
-out:
-	if (ncs != NULL)
-		g_ptr_array_unref (ncs);
-	return ret;
+	g_ptr_array_unref (ncs);
+	return TRUE;
 }
 
 struct {
@@ -931,10 +914,10 @@ out:
 }
 
 /**
- * gcm_profile_warning_to_string:
+ * cd_icc_warning_to_string:
  **/
 static const gchar *
-gcm_profile_warning_to_string (CdProfileWarning kind_enum)
+cd_icc_warning_to_string (CdProfileWarning kind_enum)
 {
 	const gchar *kind = NULL;
 	switch (kind_enum) {
@@ -978,6 +961,10 @@ gcm_profile_warning_to_string (CdProfileWarning kind_enum)
 		/* TRANSLATORS: the profile is broken */
 		kind = _("The white is not D50 white");
 		break;
+	case CD_PROFILE_WARNING_WHITEPOINT_UNLIKELY:
+		/* TRANSLATORS: the profile is broken */
+		kind = _("The whitepoint temperature is unlikely");
+		break;
 	default:
 		/* TRANSLATORS: the profile is broken */
 		kind = _("Unknown warning type");
@@ -994,14 +981,13 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 {
 	GtkWidget *widget;
 	GtkWindow *window;
-	GFile *file;
-	GcmProfile *gcm_profile = NULL;
-	GcmClut *clut_trc = NULL;
-	GcmClut *clut_vcgt = NULL;
+	CdIcc *icc = NULL;
+	GPtrArray *clut_trc = NULL;
+	GPtrArray *clut_vcgt = NULL;
 	const gchar *profile_copyright;
 	const gchar *profile_manufacturer;
 	const gchar *profile_model ;
-	const gchar *profile_datetime;
+	GDateTime *created;
 	const gchar *profile_title;
 	gchar *temp;
 	const gchar *filename;
@@ -1031,27 +1017,21 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 		goto out;
 	}
 
-	gcm_profile = gcm_profile_new ();
-	file = g_file_new_for_path (cd_profile_get_filename (profile));
-	gcm_profile_parse (gcm_profile,
-			   file,
-			   NULL);
-	g_object_unref (file);
-
 	/* set the preview widgets */
+	icc = cd_profile_load_icc (profile, CD_ICC_LOAD_FLAGS_ALL, NULL, NULL);
 	if (cd_profile_get_colorspace (profile) == CD_COLORSPACE_RGB &&
 	    cd_profile_get_kind (profile) != CD_PROFILE_KIND_NAMED_COLOR) {
-		gcm_image_set_input_profile (GCM_IMAGE(viewer->preview_widget_input), gcm_profile);
+		gcm_image_set_input_profile (GCM_IMAGE(viewer->preview_widget_input), icc);
 		gcm_image_set_abstract_profile (GCM_IMAGE(viewer->preview_widget_input), NULL);
-		gcm_image_set_output_profile (GCM_IMAGE(viewer->preview_widget_output), gcm_profile);
+		gcm_image_set_output_profile (GCM_IMAGE(viewer->preview_widget_output), icc);
 		gcm_image_set_abstract_profile (GCM_IMAGE(viewer->preview_widget_output), NULL);
 		show_section = TRUE;
 	} else if (cd_profile_get_colorspace (profile) == CD_COLORSPACE_LAB &&
 		   cd_profile_get_kind (profile) != CD_PROFILE_KIND_NAMED_COLOR) {
 		gcm_image_set_input_profile (GCM_IMAGE(viewer->preview_widget_input), NULL);
-		gcm_image_set_abstract_profile (GCM_IMAGE(viewer->preview_widget_input), gcm_profile);
+		gcm_image_set_abstract_profile (GCM_IMAGE(viewer->preview_widget_input), icc);
 		gcm_image_set_output_profile (GCM_IMAGE(viewer->preview_widget_output), NULL);
-		gcm_image_set_abstract_profile (GCM_IMAGE(viewer->preview_widget_output), gcm_profile);
+		gcm_image_set_abstract_profile (GCM_IMAGE(viewer->preview_widget_output), icc);
 		show_section = TRUE;
 	} else {
 		gcm_image_set_input_profile (GCM_IMAGE(viewer->preview_widget_input), NULL);
@@ -1065,23 +1045,18 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	if (cd_profile_get_colorspace (profile) == CD_COLORSPACE_RGB &&
 	    cd_profile_get_kind (profile) != CD_PROFILE_KIND_NAMED_COLOR) {
 		gcm_cie_widget_set_from_profile (viewer->cie_widget,
-						 gcm_profile);
+						 icc);
 		gtk_widget_show (widget);
 	} else {
 		gtk_widget_hide (widget);
 	}
 
 	/* get curve data */
-	clut_trc = gcm_profile_generate_curve (gcm_profile, 256);
-
-	/* only show if there is useful information */
-	size = 0;
-	if (clut_trc != NULL)
-		size = gcm_clut_get_size (clut_trc);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_trc"));
-	if (size > 0) {
+	clut_trc = cd_icc_get_response (icc, 256, NULL);
+	if (clut_trc != NULL) {
 		g_object_set (viewer->trc_widget,
-			      "clut", clut_trc,
+			      "data", clut_trc,
 			      NULL);
 		gtk_widget_show (widget);
 	} else {
@@ -1092,22 +1067,17 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	/* show 3d gamut hull */
 	gtk_widget_show (viewer->hull_widget);
 	gcm_hull_widget_clear (GCM_HULL_WIDGET (viewer->hull_widget));
-	ret = gcm_hull_widget_add (GCM_HULL_WIDGET (viewer->hull_widget), gcm_profile);
+	ret = gcm_hull_widget_add (GCM_HULL_WIDGET (viewer->hull_widget), icc);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_3d"));
 	gtk_widget_set_visible (widget, ret);
 #endif
 
 	/* get vcgt data */
-	clut_vcgt = gcm_profile_generate_vcgt (gcm_profile, 256);
-
-	/* only show if there is useful information */
-	size = 0;
-	if (clut_vcgt != NULL)
-		size = gcm_clut_get_size (clut_vcgt);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_vcgt"));
-	if (size > 0) {
+	clut_vcgt = cd_icc_get_vcgt (icc, 256, NULL);
+	if (clut_vcgt != NULL) {
 		g_object_set (viewer->vcgt_widget,
-			      "clut", clut_vcgt,
+			      "data", clut_vcgt,
 			      NULL);
 		gtk_widget_show (widget);
 	} else {
@@ -1176,7 +1146,7 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 			g_debug ("warnings[i]=%s", warnings[i]);
 			warning = cd_profile_warning_from_string (warnings[i]);
 			g_string_append_printf (str, "• %s\n",
-						gcm_profile_warning_to_string (warning));
+						cd_icc_warning_to_string (warning));
 		}
 		if (str->len > 0)
 			g_string_set_size (str, str->len - 1);
@@ -1185,13 +1155,13 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	}
 
 	/* set profile version */
-	filename = gcm_profile_get_version (gcm_profile);
-	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder,
-			     "label_version"));
-	gtk_label_set_label (GTK_LABEL (widget), filename);
+	temp = g_strdup_printf ("%.1f", cd_icc_get_version (icc));
+	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_version"));
+	gtk_label_set_label (GTK_LABEL (widget), temp);
+	g_free (temp);
 
 	/* set whitepoint */
-	temperature = gcm_profile_get_temperature (gcm_profile);
+	temperature = cd_icc_get_temperature (icc);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_title_temp"));
 	gtk_widget_set_visible (widget, temperature > 0);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_temp"));
@@ -1209,7 +1179,7 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	}
 
 	/* set size */
-	filesize = gcm_profile_get_size (gcm_profile);
+	filesize = cd_icc_get_size (icc);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_title_size"));
 	gtk_widget_set_visible (widget, filesize > 0);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_size"));
@@ -1220,19 +1190,19 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	}
 
 	/* set new copyright */
-	profile_copyright = gcm_profile_get_copyright (gcm_profile);
+	profile_copyright = cd_icc_get_copyright (icc, viewer->lang, NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_title_copyright"));
 	gtk_widget_set_visible (widget, profile_copyright != NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_copyright"));
 	gtk_widget_set_visible (widget, profile_copyright != NULL);
 	if (profile_copyright != NULL) {
 		temp = gcm_utils_linkify (profile_copyright);
-		gtk_label_set_label (GTK_LABEL (widget), temp);
+		gtk_label_set_label (GTK_LABEL (widget), profile_copyright);
 		g_free (temp);
 	}
 
 	/* set new manufacturer */
-	profile_manufacturer = gcm_profile_get_manufacturer (gcm_profile);
+	profile_manufacturer = cd_icc_get_manufacturer (icc, viewer->lang, NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_title_profile_manufacturer"));
 	gtk_widget_set_visible (widget, profile_manufacturer != NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_profile_manufacturer"));
@@ -1244,7 +1214,7 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	}
 
 	/* set new model */
-	profile_model = gcm_profile_get_model (gcm_profile);
+	profile_model = cd_icc_get_model (icc, viewer->lang, NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_title_profile_model"));
 	gtk_widget_set_visible (widget, profile_model != NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_profile_model"));
@@ -1256,18 +1226,22 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	}
 
 	/* set new datetime */
-	profile_datetime = gcm_profile_get_datetime (gcm_profile);
+	created = cd_icc_get_created  (icc);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_title_datetime"));
-	gtk_widget_set_visible (widget, profile_datetime != NULL);
+	gtk_widget_set_visible (widget, created != NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "label_datetime"));
-	gtk_widget_set_visible (widget, profile_datetime != NULL);
-	if (profile_datetime != NULL)
-		gtk_label_set_label (GTK_LABEL(widget), profile_datetime);
+	gtk_widget_set_visible (widget, created != NULL);
+	if (created != NULL) {
+		/* TRANSLATORS: this is the icc creation date strftime format */
+		temp = g_date_time_format (created, _("%B %e %Y, %I:%M:%S %p"));
+		gtk_label_set_label (GTK_LABEL(widget), temp);
+		g_free (temp);
+	}
 
 	/* setup named color tab */
 	ret = FALSE;
 	if (profile_kind == CD_PROFILE_KIND_NAMED_COLOR)
-		ret = gcm_viewer_add_named_colors (viewer, gcm_profile);
+		ret = gcm_viewer_add_named_colors (viewer, icc);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "vbox_named_colors"));
 	gtk_widget_set_visible (widget, ret);
 
@@ -1277,7 +1251,7 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	gtk_widget_set_visible (widget, ret);
 
 	/* set delete sensitivity */
-	ret = gcm_profile_get_can_delete (gcm_profile);
+	ret = cd_icc_get_can_delete (icc);
 	widget = GTK_WIDGET (gtk_builder_get_object (viewer->builder, "toolbutton_profile_delete"));
 	gtk_widget_set_sensitive (widget, ret);
 	if (ret) {
@@ -1295,12 +1269,12 @@ gcm_viewer_set_profile (GcmViewerPrivate *viewer, CdProfile *profile)
 	gtk_widget_set_visible (widget, show_section);
 
 out:
-	if (gcm_profile != NULL)
-		g_object_unref (gcm_profile);
+	if (icc != NULL)
+		g_object_unref (icc);
 	if (clut_trc != NULL)
-		g_object_unref (clut_trc);
+		g_ptr_array_unref (clut_trc);
 	if (clut_vcgt != NULL)
-		g_object_unref (clut_vcgt);
+		g_ptr_array_unref (clut_vcgt);
 	g_free (size_text);
 }
 
@@ -1879,6 +1853,7 @@ main (int argc, char **argv)
 	viewer->xid = xid;
 	viewer->profile_id = profile_id;
 	viewer->filename = filename;
+	viewer->lang = g_getenv ("LANG");
 
 	/* ensure single instance */
 	viewer->application = gtk_application_new ("org.gnome.ColorManager.Viewer", 0);
